#
# spec file for package python-Flask-WTF
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without     test
%{?sle15_python_module_pythons}
Name:           python-Flask-WTF
Version:        1.2.2
Release:        1.3
Summary:        WTForms support for Flask
License:        BSD-3-Clause
URL:            https://github.com/lepture/flask-wtf
Source:         https://files.pythonhosted.org/packages/source/F/Flask-WTF/flask_wtf-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
Requires:       python-WTForms
Requires:       python-Werkzeug
Requires:       python-itsdangerous
Recommends:     python-email_validator
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Flask-Babel}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module WTForms}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module itsdangerous}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
Adds WTForms support to your Flask application

%prep
%autosetup -p1 -n flask_wtf-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{_prefix}

%if %{with test}
%check
export LANG=en_US.UTF-8
# Excluded tests because of gh#wtforms/wtforms#697
%pytest -k 'not (test_set_default_message_language or test_i18n)' tests
%endif

%files %{python_files}
%license LICENSE.rst
%doc README.rst
%{python_sitelib}/flask_wtf
%{python_sitelib}/flask_wtf-%{version}.dist-info

%changelog
* Thu Nov 14 2024 Dirk Müller <dmueller@suse.com>
- update to 1.2.2:
  * Move the project to the pallets-eco organization. :pr:`602`
  * Stop support for Python 3.8. Start support for Python 3.13.
    :pr:`603`
* Mon Nov 27 2023 Antonio Larrosa <alarrosa@suse.com>
- Use %%{?sle15_python_module_pythons}
* Mon Nov 27 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.2.1:
  * Fix a bug introduced with #556 in 1.2.0 where file validators
    were editing the file fields content.
- Update to 1.2.0:
  * Add field MultipleFileField. FileRequired, FileAllowed,
    FileSize now can be used to validate multiple files
- Update to 1.1.2:
  * Fixed Flask 2.3 deprecations of werkzeug.urls.url_encode and
    flask.Markup
  * Stop support for python 3.7
  * Use pyproject.toml instead of setup.cfg
  * Fixed nested blueprint CSRF exemption
- Drop patch already included upstream:
  * flask-2.3-support.patch
* Fri Jun 30 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.1.1:
  * Fixed `validate` `extra_validators` parameter. :pr:`548`
  * Drop support for Python 3.6.
  * ``validate_on_submit`` takes a ``extra_validators`` parameters :pr:`479`
  * Stop supporting Flask-Babelex :pr:`540`
  * Support for python 3.11 :pr:`542`
  * Remove unused call to `JSONEncoder` :pr:`536`
- Add patch flask-2.3-support.patch:
  * Support Flask 2.3 changes.
- Switch to pyproject macros.
* Sat Apr  9 2022 Arun Persaud <arun@gmx.de>
- update to version 1.0.1:
  * Update compatibility with the latest Werkzeug
    release. :issue:`511`
* Sun Feb 20 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * removed patches: fix-ModuleNotFoundError-wtforms-compat.patch
    fix-ModuleNotFoundError-wtforms-widgets-html5.patch
  * AUTHORS not packaged anymore, LICENSE->LICENSE.rst
- update to version 1.0.0:
  * Deprecated items removal :pr:`484`
  * Support for alternatives captcha services :pr:`425` :pr:`342`
    :pr:`387` :issue:`384`
- changes from version 0.15.1:
  * Add "python_requires" metadata to avoid installing on unsupported
    Python versions. :pr:`442`
* Sat Aug 14 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to 0.15.1
  * Add python_requires metadata to avoid installing on unsupported
    Python versions.
- Changes from 0.15.0
  * Drop support for Python < 3.6.
  * FileSize validator.
  * Extra requirement email installs the email_validator package.
  * Fixed Flask 2.0 warnings.
  * Various documentation fixes.
  * Various CI fixes.
- Add fix-ModuleNotFoundError-wtforms-compat.patch to fix
  ModuleNotFoundError in tests/test_form.py.
- Add fix-ModuleNotFoundError-wtforms-widgets-html5.patch to fix
  ModuleNotFoundError in flask_wtf/html5.py.
- Skip test_set_default_message_language and test_i18n because of
  gh#wtforms/wtforms#697.
* Thu Jan 28 2021 Antonio Larrosa <alarrosa@suse.com>
- Define skip_python2 so we can build the package for SLE where an
  old version of python2-Flask-Babel is available (and doesn't work
  with a recent python-Werkzeug)
* Fri Dec 11 2020 Andreas Schneider <asn@cryptomilk.org>
- Add missing BR for Flask-BabelEx
* Wed Jun 10 2020 Marketa Calabkova <mcalabkova@suse.com>
- replace nose with pytest
* Sat Feb  8 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * removed python-devel dependency
  * be more specific in %%file section
- update to version 0.14.3:
  * Fix deprecated imports from "werkzeug" and "collections".
* Thu Jan 25 2018 tchvatal@suse.com
- Fix whitespace and drop the subpkg wrt previous commit
* Wed Jan 24 2018 aboe76@gmail.com
- Added python-itsdangerous requirements
- disabled sphinx build html docs and doc packages because of build errors.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to Version 0.14.2
  * Fix bug where ``FlaskForm`` assumed ``meta`` argument was not ``None`` if it
    was passed. (`#278`_)
- Update to Version 0.14.1
  * Fix bug where the file validators would incorrectly identify an empty file as
    valid data. (`#276`_, `#277`_)
- Update to Version 0.14
  * Use itsdangerous to sign CSRF tokens and check expiration instead of doing it
    ourselves. (`#264`_)
  * Remove the ``app`` attribute from ``CsrfProtect``, use ``current_app``.
    (`#264`_)
  * ``CsrfProtect`` protects the ``DELETE`` method by default. (`#264`_)
  * The same CSRF token is generated for the lifetime of a request. It is exposed
    as ``request.csrf_token`` for use during testing. (`#227`_, `#264`_)
  * ``CsrfProtect.error_handler`` is deprecated. (`#264`_)
  * Use ``Form.Meta`` instead of deprecated ``SecureForm`` for CSRF (and
    everything else). (`#216`_, `#271`_)
  * Provide ``WTF_CSRF_FIELD_NAME`` to configure the name of the CSRF token.
    (`#271`_)
  * ``validate_csrf`` raises ``wtforms.ValidationError`` with specific messages
    instead of returning ``True`` or ``False``. This breaks anything that was
    calling the method directly. (`#239`_, `#271`_)
  * ``CsrfProtect`` is renamed to ``CSRFProtect``. A deprecation warning is issued
    when using the old name. ``CsrfError`` is renamed to ``CSRFError`` without
    deprecation. (`#271`_)
  * ``FileField`` is deprecated because it no longer provides functionality over
    the provided validators. Use ``wtforms.FileField`` directly. (`#272`_)
- Update to Version 0.13.1
  * Deprecation warning for ``Form`` is shown during ``__init__`` instead of immediately when subclassing. (`#262`_)
  * Don't use ``pkg_resources`` to get version, for compatibility with GAE. (`#261`_)
- Update to Version 0.13
  * ``Form`` is renamed to ``FlaskForm`` in order to avoid name collision with WTForms's base class.  Using ``Form`` will show a deprecation warning. (`#250`_)
  * ``hidden_tag`` no longer wraps the hidden inputs in a hidden div.  This is valid HTML5 and any modern HTML parser will behave correctly. (`#217`_, `#193`_)
  * ``flask_wtf.html5`` is deprecated.  Import directly from ``wtforms.fields.html5``. (`#251`_)
  * ``is_submitted`` is true for ``PATCH`` and ``DELETE`` in addition to ``POST`` and ``PUT``. (`#187`_)
  * ``generate_csrf`` takes a ``token_key`` parameter to specify the key stored in the session. (`#206`_)
  * ``generate_csrf`` takes a ``url_safe`` parameter to allow the token to be used in URLs. (`#206`_)
  * ``form.data`` can be accessed multiple times without raising an exception. (`#248`_)
  * File extension with multiple parts (``.tar.gz``) can be used in the ``FileAllowed`` validator. (`#201`_)
- Update to Version 0.12
  * Abstract protect_csrf() into a separate method
  * Update reCAPTCHA configuration
  * Fix reCAPTCHA error handle
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Wed Mar 25 2015 aboe76@gmail.com
- Updated to 0.11
  - Use the new reCAPTCHA API via #164.
  - Add configuration: WTF_CSRF_HEADERS via #159.
  - Support customize hidden tags via #150.
  - And many more bug fixes
* Wed Oct 22 2014 aboe76@gmail.com
- Updated to 0.10.2
  - Update translation for reCaptcha via #146.
  - Update RECAPTCHA API SERVER URL via #145.
  - Update requirement Werkzeug>=0.9.5
  - Fix CsrfProtect exempt for blueprints via #143.
  - Add configuration: WTF_CSRF_METHODS
  - Support WTForms 2.0 now
  - Fix csrf validation without time limit (time_limit=False)
  - CSRF exempt supports blueprint #111.
* Wed Jul  2 2014 aboe76@gmail.com
- Updated to 0.9.5
- Add configuration: WTF_CSRF_METHODS.
* Wed Feb 12 2014 aboe76@gmail.com
- Initial Upload: Flask-WTF 0.8.4 Released 2013/12/20
- Bugfix for csrf module when form has a prefix
- Compatible support for wtforms2
- Remove file API for FileField
